#load packages we will need
library(biomod2)
library(rworldmap)
library(rgdal) 
library(dismo)
library(SDMTools)
library(adehabitat)
library(MASS)
library(randomForest)

setwd("/mnt/gfs/anahi/jack")
#setwd("E:/collaborations/jack/R")

#load bioclim data and then select the area that will be used to project
bio1=raster("./cur_climate/bio1.bil") #Annual Mean Temperature
bio2=raster("./cur_climate/bio2.bil")
bio3=raster("./cur_climate/bio3.bil")
bio4=raster("./cur_climate/bio4.bil")
bio5=raster("./cur_climate/bio5.bil")
bio6=raster("./cur_climate/bio6.bil")
bio7=raster("./cur_climate/bio7.bil")
bio8=raster("./cur_climate/bio8.bil")
bio9=raster("./cur_climate/bio9.bil")
bio10=raster("./cur_climate/bio10.bil") #Mean Temperature of Warmest Quarter 
bio11=raster("./cur_climate/bio11.bil") #Mean Temperature of Coldest Quarter
bio12=raster("./cur_climate/bio12.bil") #Annual Precipitation
bio13=raster("./cur_climate/bio13.bil")
bio14=raster("./cur_climate/bio14.bil")
bio15=raster("./cur_climate/bio15.bil")
bio16=raster("./cur_climate/bio16.bil")
bio17=raster("./cur_climate/bio17.bil")
bio18=raster("./cur_climate/bio18.bil") #Precipitation of Warmest Quarter
bio19=raster("./cur_climate/bio19.bil") #Precipitation of Coldest Quarter

setwd("/mnt/gfs/anahi/jack/aridZones")
#setwd("E:/collaborations/jack/R/aridZones")

#read data with assignments
clim=read.csv("aridZonesData2.csv", header=T)
clim=clim[clim$decimalLat>16,]
clim=clim[clim$decimalLon<c(-97),]

# which records are duplicates
dups <- duplicated(clim[, 4:5])
# remove duplicates
clim <- clim[!dups, ]
#summary(clim)
#summary(clim[,15])

#add climatic data
aridData=cbind((as.matrix(extract(bio1,clim[,c(5,4)]))),clim)
aridData=cbind((as.matrix(extract(bio2,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio3,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio4,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio5,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio6,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio7,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio8,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio9,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio10,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio11,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio12,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio13,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio14,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio15,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio16,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio17,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio18,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio19,clim[,c(5,4)]))),aridData)

aridData=na.omit(aridData)
#change column names for climatic variables
newcols=c("bio19","bio18","bio17","bio16","bio15","bio14","bio13","bio12","bio11","bio10","bio9","bio8",
          "bio7","bio6","bio5","bio4","bio3","bio2","bio1",colnames(clim))
colnames(aridData)<-newcols

#transform variables to normalize them
aridData[,17]<-(aridData[,17])^2
aridData[,13]<-(aridData[,13])^2
aridData[,11]<-(aridData[,11])^2
aridData[,c(8,6,5,2)]<-(aridData[,c(8,6,5,2)])^1/3




###################################
#####RF for resampled data#########
###################################


#memory.limit(size=50000)
setwd("/mnt/gfs/anahi/jack/aridZones/DFAaridDownsample30")
#setwd("E:/collaborations/jack/R/aridZones/testAccuracy")
##################
binded.Predict=c()
for (i in 1:100) {
aridSub=c()
aridSub=aridData[aridData$complex!="Ammospermophilus leucurus",]
C=aridSub[aridSub$group=="B",]
Csel=C[(sample(nrow(C), size=22817, replace=T)),]
NC=aridSub[aridSub$group=="NB",]
aridSub=rbind(Csel,NC)

fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                  data=aridSub)

Contribution=(fitDFAarid[[4]])
write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)

fit.hatarid=predict(fitDFAarid)
binded.dataArid=c()
binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)

ctarid <- table(binded.dataArid$group, fit.hatarid$class)
diag(prop.table(ctarid, 1))
write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)

Ammospermophilus=aridData[aridData$complex=="Ammospermophilus leucurus",]
PredictionNEWprob <- predict(fitDFAarid,Ammospermophilus,type="prob") #calculates probability for each group
PredictionNEW <- predict(fitDFAarid,Ammospermophilus)
binded.dataDFAarid=cbind(Ammospermophilus, PredictionNEWprob,PredictionNEW)
binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)

}  
#plot(binded.dataDFAarid$PredictionNEW, main="Prediction Ammospermophilus", beside=F)
#dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Ammospermophilus.tif")
#dev.off()

  
   
  ##################
 binded.Predict=c()
 for (i in 1:100) {
    aridSub=c()
  aridSub=aridData[aridData$complex!="Anaxyrus.punctatus.group",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Anaxyrus=aridData[aridData$complex=="Anaxyrus.punctatus.group",]
  PredictionNEWprob <- predict(fitDFAarid,Anaxyrus,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Anaxyrus)
  binded.dataDFAarid=cbind(Anaxyrus, PredictionNEWprob,PredictionNEW)
binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)

  }  
  
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Anaxyrus", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Anaxyrus.tif")
 # dev.off()
  
  ##################
 binded.Predict=c()
 for (i in 1:100) {
   aridSub=c()
  aridSub=aridData[aridData$complex!="Auriparus flaviceps",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=13016, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Auriparus=aridData[aridData$complex=="Auriparus flaviceps",]
  PredictionNEWprob <- predict(fitDFAarid,Auriparus,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Auriparus)
  binded.dataDFAarid=cbind(Auriparus, PredictionNEWprob,PredictionNEW)
 binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
 write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)
 
 

 
 }  
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Auriparus", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Auriparus.tif")
 # dev.off()
  
  ##################
 binded.Predict=c()
 for (i in 1:100) {
    aridSub=c()
  aridSub=aridData[aridData$complex!="Callilepla.californica-gambelli",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Callilepla=aridData[aridData$complex=="Callilepla.californica-gambelli",]
  PredictionNEWprob <- predict(fitDFAarid,Callilepla,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Callilepla)
  binded.dataDFAarid=cbind(Callilepla, PredictionNEWprob,PredictionNEW)
binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)



  }
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Callilepla", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Callilepla.tif")
 # dev.off()
  

  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Campylorhynchus brunneicapillus",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=14262, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Campylo=aridData[aridData$complex=="Campylorhynchus brunneicapillus",]
  PredictionNEWprob <- predict(fitDFAarid,Campylo,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Campylo)
  binded.dataDFAarid=cbind(Campylo, PredictionNEWprob,PredictionNEW)
  binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
  write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)


}
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Campylo", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Campylorhynchus.tif")
 # dev.off()
  
  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Chaetodipus.baileyi.group",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Chaeto=aridData[aridData$complex=="Chaetodipus.baileyi.group",]
  PredictionNEWprob <- predict(fitDFAarid,Chaeto,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Chaeto)
  binded.dataDFAarid=cbind(Chaeto, PredictionNEWprob,PredictionNEW)
  binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
  write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)
  
  }
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Chaeto", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Chaetodipus.tif")
 # dev.off()
  
 
  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Dipodomys.merriami.group",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  
  Dipod=aridData[aridData$complex=="Dipodomys.merriami.group",]
  PredictionNEWprob <- predict(fitDFAarid,Dipod,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Dipod)
  binded.dataDFAarid=cbind(Dipod, PredictionNEWprob,PredictionNEW)
  
    Dipod=aridData[aridData$complex=="Dipodomys.merriami.group",]
    PredictionNEWprob <- predict(fitDFAarid,Dipod,type="prob") #calculates probability for each group
    PredictionNEW <- predict(fitDFAarid,Dipod)
    binded.dataDFAarid=cbind(Dipod, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
    write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)

  }
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Dipod", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Dipodomys.tif")
 # dev.off()
  
  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Peromyscus.group",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Peromys=aridData[aridData$complex=="Peromyscus.group",]
  PredictionNEWprob <- predict(fitDFAarid,Peromys,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Peromys)
  binded.dataDFAarid=cbind(Peromys, PredictionNEWprob,PredictionNEW)
  binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
  write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)
 
  }
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Peromyscus", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Peromyscus.tif")
 # dev.off()
  
  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Pi.aberti-crissalis",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Pipi=aridData[aridData$complex=="Pi.aberti-crissalis",]
  PredictionNEWprob <- predict(fitDFAarid,Pipi,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Pipi)
  binded.dataDFAarid=cbind(Pipi, PredictionNEWprob,PredictionNEW)
  binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)


}
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Pi.aberti-crissalis", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Pi.aberti-crissalis.tif")
 # dev.off()
  
 
  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Pipilo fuscus",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=22782, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Pipilio=aridData[aridData$complex=="Pipilo fuscus",]
  PredictionNEWprob <- predict(fitDFAarid,Pipilio,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Pipilio)
  binded.dataDFAarid=cbind(Pipilio, PredictionNEWprob,PredictionNEW)
  binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
  write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)
  
  }
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Pipilio", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Pipilio.tif")
 # dev.off()
  
  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Po.melanura-californica",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Po.mel.calif=aridData[aridData$complex=="Po.melanura-californica",]
  PredictionNEWprob <- predict(fitDFAarid,Po.mel.calif,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Po.mel.calif)
  binded.dataDFAarid=cbind(Po.mel.calif, PredictionNEWprob,PredictionNEW)
  binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)


}
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Po.mel.calif", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Po.melanura-californica.tif")
 # dev.off()
  
  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="T.cinereum-binderei",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Tcin.bin=aridData[aridData$complex=="T.cinereum-binderei",]
  PredictionNEWprob <- predict(fitDFAarid,Tcin.bin,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Tcin.bin)
  binded.dataDFAarid=cbind(Tcin.bin, PredictionNEWprob,PredictionNEW)
  binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
  write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)
 
  }
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction T.cin.bin", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="T.cinereum-binderei.tif")
 # dev.off()
  
  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Toxostoma lecontei",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=23171, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)

  Toxos=aridData[aridData$complex=="Toxostoma lecontei",]
  PredictionNEWprob <- predict(fitDFAarid,Toxos,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Toxos)
  binded.dataDFAarid=cbind(Toxos, PredictionNEWprob,PredictionNEW)
  binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)


}
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction Toxostoma", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Toxostoma.tif")
 # dev.off()
  
  ##################
  binded.Predict=c()
  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="V.luciae-ruficapilla",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                    data=aridSub)
  
  Contribution=(fitDFAarid[[4]])
  write.table(Contribution,file="fitDFAaridDownsample.csv", sep=",", append=T)
  
  fit.hatarid=predict(fitDFAarid)
  binded.dataArid=c()
  binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
  write.table(binded.dataArid,file="bindedDataDFAAridDownsample.csv",sep=",", append=T)
  
  ctarid <- table(binded.dataArid$group, fit.hatarid$class)
  diag(prop.table(ctarid, 1))
  write.table(ctarid, file="confusionTableDFA_aridDownsample.csv", sep=",",append=T)
  
  Vluci.rufi=aridData[aridData$complex=="V.luciae-ruficapilla",]
  PredictionNEWprob <- predict(fitDFAarid,Vluci.rufi,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitDFAarid,Vluci.rufi)
  binded.dataDFAarid=cbind(Vluci.rufi, PredictionNEWprob,PredictionNEW)
  binded.Predict=rbind(binded.dataDFAarid,binded.Predict)
  write.table(binded.Predict[,c(20,32:41)], file="PredictOutspDFAaridDown.csv", sep=',', append=T)
  
  

  }
 # plot(binded.dataDFAarid$PredictionNEW, main="Prediction V.lu.ruf", beside=F)
 # dev.copy(tiff,width = 1000, height = 1000, compression="none",file="V.luciae-ruficapilla.tif")
 # dev.off()
  
 
 Predictions=as.data.frame(read.table(file="PredictOutspDFAaridDown.csv", header=T, row.names=NULL,
 fill=T, encoding="UTF-8", sep=","))
 
colnames(Predictions)

PredictNC=Predictions[Predictions$group=="NB", 7]
PredictC=Predictions[Predictions$group=="B", 7]

NC=as.data.frame(table(PredictNC))
C=as.data.frame(table(PredictC))

totalNC=sum(NC$Freq)
totalC=sum(C$Freq)
total=sum(totalNC,totalC)

accuracyC=C[C$PredictC=="B",2]/totalC
accuracyNC=NC[NC$PredictNC=="NB",2]/totalNC
accuracytotal=(C[C$PredictC=="B",2]+NC[NC$PredictNC=="NB",2])/total
accuracies=cbind(accuracyC, accuracyNC,accuracytotal)
write.csv(accuracies, file='accuracyDownsamDFAarid.csv')
