#load packages we will need
library(biomod2)
library(rworldmap)
library(rgdal) 
library(dismo)
library(SDMTools)
library(adehabitat)
library(MASS)
library(randomForest)

setwd("/mnt/gfs/anahi/jack")
#setwd("E:/collaborations/jack/R")

#load bioclim data and then select the area that will be used to project
bio1=raster("./cur_climate/bio1.bil") #Annual Mean Temperature
bio2=raster("./cur_climate/bio2.bil")
bio3=raster("./cur_climate/bio3.bil")
bio4=raster("./cur_climate/bio4.bil")
bio5=raster("./cur_climate/bio5.bil")
bio6=raster("./cur_climate/bio6.bil")
bio7=raster("./cur_climate/bio7.bil")
bio8=raster("./cur_climate/bio8.bil")
bio9=raster("./cur_climate/bio9.bil")
bio10=raster("./cur_climate/bio10.bil") #Mean Temperature of Warmest Quarter 
bio11=raster("./cur_climate/bio11.bil") #Mean Temperature of Coldest Quarter
bio12=raster("./cur_climate/bio12.bil") #Annual Precipitation
bio13=raster("./cur_climate/bio13.bil")
bio14=raster("./cur_climate/bio14.bil")
bio15=raster("./cur_climate/bio15.bil")
bio16=raster("./cur_climate/bio16.bil")
bio17=raster("./cur_climate/bio17.bil")
bio18=raster("./cur_climate/bio18.bil") #Precipitation of Warmest Quarter
bio19=raster("./cur_climate/bio19.bil") #Precipitation of Coldest Quarter

setwd("/mnt/gfs/anahi/jack/aridZones")
#setwd("E:/collaborations/jack/R/aridZones")

#read data with assignments
clim=read.csv("aridZonesData2.csv", header=T)
clim=clim[clim$decimalLat>16,]
clim=clim[clim$decimalLon<c(-97),]

# which records are duplicates
dups = duplicated(clim[, 4:5])
# remove duplicates
clim = clim[!dups, ]
#summary(clim)
#summary(clim[,15])

#add climatic data
aridData=cbind((as.matrix(extract(bio1,clim[,c(5,4)]))),clim)
aridData=cbind((as.matrix(extract(bio2,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio3,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio4,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio5,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio6,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio7,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio8,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio9,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio10,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio11,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio12,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio13,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio14,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio15,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio16,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio17,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio18,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio19,clim[,c(5,4)]))),aridData)

aridData=na.omit(aridData)
#change column names for climatic variables
newcols=c("bio19","bio18","bio17","bio16","bio15","bio14","bio13","bio12","bio11","bio10","bio9","bio8",
          "bio7","bio6","bio5","bio4","bio3","bio2","bio1",colnames(clim))
colnames(aridData)<-newcols

#transform variables to normalize them
aridData[,17]<-(aridData[,17])^2
aridData[,13]<-(aridData[,13])^2
aridData[,11]<-(aridData[,11])^2
aridData[,c(8,6,5,2)]<-(aridData[,c(8,6,5,2)])^1/3




###################################
#####RF for resampled data#########
###################################


#memory.limit(size=50000)
setwd("/mnt/gfs/anahi/jack/aridZones/aridRFresample100")
#setwd("E:/collaborations/jack/R/aridZones/testAccuracy")
##################
levelscomplex=levels(aridData$complex)
for (k in 1:length(levelscomplex)) {
  aridSub=aridData[aridData$complex!=levelscomplex[k],]

binded.Predict=c()  
  for (i in 1:100) {
C=aridSub[aridSub$group=="B",]
Csel=C[(sample(nrow(C), size=1500, replace=T)),]
NC=aridSub[aridSub$group=="NB",]
NCsel=NC[(sample(nrow(NC), size=1500, replace=T)),]
aridSub=rbind(Csel,NCsel)

  fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                            data=aridSub, importance=TRUE, ntree=5000, replace=T)
  
  Contribution=fitRFarid$importance
  write.table(Contribution,file="fitRFaridResamp1500.csv", sep=",", append=T)
  
  PredictionArid <- predict(fitRFarid)
  binded.dataRFarid=c()
  binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
  write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl1500.csv", sep=",", append=T)
 
  ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
  diag(prop.table(ctRFarid, 1))
  write.table(ctRFarid, file="confusionTableRF_aridResampled1500.csv", sep=",",append=T)
  
    Species=aridData[aridData$complex==levelscomplex[k],]
    PredictionNEWprob <- predict(fitRFarid,Species,type="prob") #calculates probability for each group
    PredictionNEW <- predict(fitRFarid,Species)
    binded.dataRFPNW=cbind(Species, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFPNW,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFarid1500.csv", sep=',', append=T)
}
}
  
levelscomplex=levels(aridData$complex)
for (k in 1:length(levelscomplex)) {
  aridSub=aridData[aridData$complex!=levelscomplex[k],]

binded.Predict=c()  
  for (i in 1:100) {
    C=aridSub[aridSub$group=="B",]
    Csel=C[(sample(nrow(C), size=5000, replace=T)),]
    NC=aridSub[aridSub$group=="NB",]
    NCsel=NC[(sample(nrow(NC), size=5000, replace=T)),]
    aridSub=rbind(Csel,NCsel)
    
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp5000.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl5000.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled5000.csv", sep=",",append=T)

    Species=aridData[aridData$complex==levelscomplex[k],]
    PredictionNEWprob <- predict(fitRFarid,Species,type="prob") #calculates probability for each group
    PredictionNEW <- predict(fitRFarid,Species)
    binded.dataRFPNW=cbind(Species, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFPNW,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFarid5000.csv", sep=',', append=T)
  }
}

levelscomplex=levels(aridData$complex)
for (k in 1:length(levelscomplex)) {
  aridSub=aridData[aridData$complex!=levelscomplex[k],]
  
binded.Predict=c()  
  for (i in 1:100) {
    C=aridSub[aridSub$group=="B",]
    Csel=C[(sample(nrow(C), size=13500, replace=T)),]
    NC=aridSub[aridSub$group=="NB",]
    NCsel=NC[(sample(nrow(NC), size=13500, replace=T)),]
    aridSub=rbind(Csel,NCsel)
    
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp13500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl13500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled13500.csv", sep=",",append=T)

    Species=aridData[aridData$complex==levelscomplex[k],]
    PredictionNEWprob <- predict(fitRFarid,Species,type="prob") #calculates probability for each group
    PredictionNEW <- predict(fitRFarid,Species)
    binded.dataRFPNW=cbind(Species, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFPNW,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFarid13500.csv", sep=',', append=T)
  }
}


levelscomplex=levels(aridData$complex)
for (k in 1:length(levelscomplex)) {
  aridSub=aridData[aridData$complex!=levelscomplex[k],]

binded.Predict=c()  
  for (i in 1:100) {
    C=aridSub[aridSub$group=="B",]
    Csel=C[(sample(nrow(C), size=25000, replace=T)),]
    NC=aridSub[aridSub$group=="NB",]
    NCsel=NC[(sample(nrow(NC), size=25000, replace=T)),]
    aridSub=rbind(Csel,NCsel)
    
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp25000.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl25000.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled25000.csv", sep=",",append=T)

    Species=aridData[aridData$complex==levelscomplex[k],]
    PredictionNEWprob <- predict(fitRFarid,Species,type="prob") #calculates probability for each group
    PredictionNEW <- predict(fitRFarid,Species)
    binded.dataRFPNW=cbind(Species, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFPNW,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFarid25000.csv", sep=',', append=T)

  }
}
