#load packages we will need
library(biomod2)
library(rworldmap)
#library(rgdal) 
library(dismo)
library(SDMTools)
library(adehabitat)
library(MASS)
library(randomForest)

setwd("/mnt/gfs/anahi/jack")

#load bioclim data and then select the area that will be used to project
bio1=raster("./cur_climate/bio1.bil") #Annual Mean Temperature
bio2=raster("./cur_climate/bio2.bil")
bio3=raster("./cur_climate/bio3.bil")
bio4=raster("./cur_climate/bio4.bil")
bio5=raster("./cur_climate/bio5.bil")
bio6=raster("./cur_climate/bio6.bil")
bio7=raster("./cur_climate/bio7.bil")
bio8=raster("./cur_climate/bio8.bil")
bio9=raster("./cur_climate/bio9.bil")
bio10=raster("./cur_climate/bio10.bil") #Mean Temperature of Warmest Quarter 
bio11=raster("./cur_climate/bio11.bil") #Mean Temperature of Coldest Quarter
bio12=raster("./cur_climate/bio12.bil") #Annual Precipitation
bio13=raster("./cur_climate/bio13.bil")
bio14=raster("./cur_climate/bio14.bil")
bio15=raster("./cur_climate/bio15.bil")
bio16=raster("./cur_climate/bio16.bil")
bio17=raster("./cur_climate/bio17.bil")
bio18=raster("./cur_climate/bio18.bil") #Precipitation of Warmest Quarter
bio19=raster("./cur_climate/bio19.bil") #Precipitation of Coldest Quarter

setwd("/mnt/gfs/anahi/jack/aridZones")
#read data with assignments
clim=read.csv("aridZonesData2.csv", header=T)
clim=clim[clim$decimalLat>16,]
clim=clim[clim$decimalLon<c(-97),]

# which records are duplicates (only for the first 10 columns)?
dups <- duplicated(clim[, 4:5])
# remove duplicates
clim <- clim[!dups, ]
#summary(clim)
#summary(clim[,15])

#add climatic data
aridData=cbind((as.matrix(extract(bio1,clim[,c(5,4)]))),clim)
aridData=cbind((as.matrix(extract(bio2,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio3,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio4,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio5,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio6,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio7,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio8,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio9,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio10,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio11,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio12,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio13,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio14,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio15,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio16,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio17,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio18,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio19,clim[,c(5,4)]))),aridData)

aridData=na.omit(aridData)
#change column names for climatic variables
newcols=c("bio19","bio18","bio17","bio16","bio15","bio14","bio13","bio12","bio11","bio10","bio9","bio8",
          "bio7","bio6","bio5","bio4","bio3","bio2","bio1",colnames(clim))
colnames(aridData)<-newcols

#transform variables to normalize them
aridData[,17]<-(aridData[,17])^2
aridData[,13]<-(aridData[,13])^2
aridData[,11]<-(aridData[,11])^2
aridData[,c(8,6,5,2)]<-(aridData[,c(8,6,5,2)])^1/3



##########################################################################
######################RUN DFA ANALYSIS WITH RESAMPLING####################
##########################################################################
setwd("/mnt/gfs/anahi/jack/aridZones/DFAResampl100")

levelscomplex=levels(aridData$complex)
for (k in 1:length(levelscomplex)) {
  aridSub=aridData[aridData$complex!=levelscomplex[k],]
  
  for (i in 1:100) {
    C=aridSub[aridSub$group=="B",]
    Csel=C[(sample(nrow(C), size=1500, replace=T)),]
    NC=aridSub[aridSub$group=="NB",]
    NCsel=NC[(sample(nrow(NC), size=1500, replace=T)),]
    aridSub=rbind(Csel,NCsel)

    rownames(aridSub) <- seq(length=nrow(aridSub))
    
    fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                      data=aridSub)
    
    Contribution=(fitDFAarid[[4]])
    write.table(Contribution,file="fitDFAaridResamp1500.csv", sep=",", append=T)
    
    fit.hatarid=predict(fitDFAarid)
    binded.dataArid=c()
    binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
    write.table(binded.dataArid,file="bindedDataDFAAridResamp1500.csv",sep=",", append=T)
    
    ctarid <- table(binded.dataArid$group, fit.hatarid$class)
    diag(prop.table(ctarid, 1))
    write.table(ctarid, file="confusionTableDFA_aridResampled1500.csv", sep=",",append=T)
    
    Species=aridData[aridData$complex==levelscomplex[k],]
    PredictionNEWprob <- predict(fitDFAarid,Species,type="prob") #calculates probability for each group
    PredictionNEW <- predict(fitDFAarid,Species)
    binded.dataDFAarid=cbind(Species, PredictionNEWprob,PredictionNEW)
    write.table(binded.dataDFAarid, file="PredictDFAaridSpeciesout1500.csv", sep=',', append=T)
    
  }  
}


levelscomplex=levels(aridData$complex)
for (k in 1:length(levelscomplex)) {
  aridSub=c()
  aridSub=aridData[aridData$complex!=levelscomplex[k],]
  
  for (i in 1:100) {
    C=aridSub[aridSub$group=="B",]
    Csel=C[(sample(nrow(C), size=5000, replace=T)),]
    NC=aridSub[aridSub$group=="NB",]
    NCsel=NC[(sample(nrow(NC), size=5000, replace=T)),]
    aridSub=rbind(Csel,NCsel)
    levelsData=levels(aridSub$group)
    
    rownames(aridSub) <- seq(length=nrow(aridSub))
    
    fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                      data=aridSub)
    
    Contribution=(fitDFAarid[[4]])
    write.table(Contribution,file="fitDFAaridResamp5000.csv", sep=",", append=T)
    
    fit.hatarid=predict(fitDFAarid)
    binded.dataArid=c()
    binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
    write.table(binded.dataArid,file="bindedDataDFAAridResamp5000.csv",sep=",", append=T)
    
    ctarid <- table(binded.dataArid$group, fit.hatarid$class)
    diag(prop.table(ctarid, 1))
    write.table(ctarid, file="confusionTableDFA_aridResampled5000.csv", sep=",",append=T)
  
    Species=aridData[aridData$complex==levelscomplex[k],]
    PredictionNEWprob <- predict(fitDFAarid,Species,type="prob") #calculates probability for each group
    PredictionNEW <- predict(fitDFAarid,Species)
    binded.dataDFAarid=cbind(Species, PredictionNEWprob,PredictionNEW)
    write.table(binded.dataDFAarid, file="PredictDFAaridSpeciesout5000.csv", sep=',', append=T)
  }
}

levelscomplex=levels(aridData$complex)
for (k in 1:length(levelscomplex)) {
  aridSub=c()
  aridSub=aridData[aridData$complex!=levelscomplex[k],]
  
  for (i in 1:100) {
    C=aridSub[aridSub$group=="B",]
    Csel=C[(sample(nrow(C), size=13500, replace=T)),]
    NC=aridSub[aridSub$group=="NB",]
    NCsel=NC[(sample(nrow(NC), size=13500, replace=T)),]
    aridSub=rbind(Csel,NCsel)
    levelsData=levels(aridSub$group)
    
    rownames(aridSub) <- seq(length=nrow(aridSub))
    
    fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                      data=aridSub)
    
    Contribution=(fitDFAarid[[4]])
    write.table(Contribution,file="fitDFAaridResamp13500.csv", sep=",", append=T)
    
    fit.hatarid=predict(fitDFAarid)
    binded.dataArid=c()
    binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
    write.table(binded.dataArid,file="bindedDataDFAAridResamp13500.csv",sep=",", append=T)
    
    ctarid <- table(binded.dataArid$group, fit.hatarid$class)
    diag(prop.table(ctarid, 1))
    write.table(ctarid, file="confusionTableDFA_aridResampled13500.csv", sep=",",append=T)
  
      Species=aridData[aridData$complex==levelscomplex[k],]
      PredictionNEWprob <- predict(fitDFAarid,Species,type="prob") #calculates probability for each group
      PredictionNEW <- predict(fitDFAarid,Species)
      binded.dataDFAarid=cbind(Species, PredictionNEWprob,PredictionNEW)
      write.table(binded.dataDFAarid, file="PredictDFAaridSpeciesout13500.csv", sep=',', append=T)

  }  
}

levelscomplex=levels(aridData$complex)
for (k in 1:length(levelscomplex)) {
  aridSub=c()
  aridSub=aridData[aridData$complex!=levelscomplex[k],]
  
  for (i in 1:100) {
    C=aridSub[aridSub$group=="B",]
    Csel=C[(sample(nrow(C), size=25000, replace=T)),]
    NC=aridSub[aridSub$group=="NB",]
    NCsel=NC[(sample(nrow(NC), size=25000, replace=T)),]
    aridSub=rbind(Csel,NCsel)
    levelsData=levels(aridSub$group)
    
    rownames(aridSub) <- seq(length=nrow(aridSub))
    
    fitDFAarid <- lda(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon, 
                      data=aridSub)
    
    Contribution=(fitDFAarid[[4]])
    write.table(Contribution,file="fitDFAaridResamp25000.csv", sep=",", append=T)
    
    fit.hatarid=predict(fitDFAarid)
    binded.dataArid=c()
    binded.dataArid=cbind(aridSub, fit.hatarid$posterior) # bind initial data table with predicted values
    write.table(binded.dataArid,file="bindedDataDFAAridResamp25000.csv",sep=",", append=T)
    
    ctarid <- table(binded.dataArid$group, fit.hatarid$class)
    diag(prop.table(ctarid, 1))
    write.table(ctarid, file="confusionTableDFA_aridResampled25000.csv", sep=",",append=T)
  
      Species=aridData[aridData$complex==levelscomplex[k],]
      PredictionNEWprob <- predict(fitDFAarid,Species,type="prob") #calculates probability for each group
      PredictionNEW <- predict(fitDFAarid,Species)
      binded.dataDFAarid=cbind(Species, PredictionNEWprob,PredictionNEW)
      write.table(binded.dataDFAarid, file="PredictDFAaridSpeciesout25000.csv", sep=',', append=T)

  }  
}

