#load packages we will need
library(biomod2)
library(rworldmap)
library(rgdal) 
library(dismo)
library(SDMTools)
library(adehabitat)
library(MASS)
library(randomForest)

setwd("/mnt/gfs/anahi/jack")
#setwd("E:/collaborations/jack/R")

#load bioclim data and then select the area that will be used to project
bio1=raster("./cur_climate/bio1.bil") #Annual Mean Temperature
bio2=raster("./cur_climate/bio2.bil")
bio3=raster("./cur_climate/bio3.bil")
bio4=raster("./cur_climate/bio4.bil")
bio5=raster("./cur_climate/bio5.bil")
bio6=raster("./cur_climate/bio6.bil")
bio7=raster("./cur_climate/bio7.bil")
bio8=raster("./cur_climate/bio8.bil")
bio9=raster("./cur_climate/bio9.bil")
bio10=raster("./cur_climate/bio10.bil") #Mean Temperature of Warmest Quarter 
bio11=raster("./cur_climate/bio11.bil") #Mean Temperature of Coldest Quarter
bio12=raster("./cur_climate/bio12.bil") #Annual Precipitation
bio13=raster("./cur_climate/bio13.bil")
bio14=raster("./cur_climate/bio14.bil")
bio15=raster("./cur_climate/bio15.bil")
bio16=raster("./cur_climate/bio16.bil")
bio17=raster("./cur_climate/bio17.bil")
bio18=raster("./cur_climate/bio18.bil") #Precipitation of Warmest Quarter
bio19=raster("./cur_climate/bio19.bil") #Precipitation of Coldest Quarter

setwd("/mnt/gfs/anahi/jack/aridZones")
#setwd("E:/collaborations/jack/R/aridZones")

#read data with assignments
clim=read.csv("aridZonesData2.csv", header=T)
clim=clim[clim$decimalLat>16,]
clim=clim[clim$decimalLon<c(-97),]

# which records are duplicates
dups <- duplicated(clim[, 4:5])
# remove duplicates
clim <- clim[!dups, ]
#summary(clim)
#summary(clim[,15])

#add climatic data
aridData=cbind((as.matrix(extract(bio1,clim[,c(5,4)]))),clim)
aridData=cbind((as.matrix(extract(bio2,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio3,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio4,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio5,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio6,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio7,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio8,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio9,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio10,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio11,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio12,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio13,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio14,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio15,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio16,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio17,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio18,clim[,c(5,4)]))),aridData)
aridData=cbind((as.matrix(extract(bio19,clim[,c(5,4)]))),aridData)

aridData=na.omit(aridData)
#change column names for climatic variables
newcols=c("bio19","bio18","bio17","bio16","bio15","bio14","bio13","bio12","bio11","bio10","bio9","bio8",
          "bio7","bio6","bio5","bio4","bio3","bio2","bio1",colnames(clim))
colnames(aridData)<-newcols

#transform variables to normalize them
aridData[,17]<-(aridData[,17])^2
aridData[,13]<-(aridData[,13])^2
aridData[,11]<-(aridData[,11])^2
aridData[,c(8,6,5,2)]<-(aridData[,c(8,6,5,2)])^1/3




###################################
#####RF for resampled data#########
###################################


#memory.limit(size=50000)
setwd("/mnt/gfs/anahi/jack/aridZones/RFdownsampleby10/1")
#setwd("E:/collaborations/jack/R/aridZones/testAccuracy")
##################
binded.Predict=c()  
for (i in 1:1000) {
aridSub=c()
aridSub=aridData[aridData$complex!="Ammospermophilus leucurus",]
C=aridSub[aridSub$group=="B",]
Csel=C[(sample(nrow(C), size=22817, replace=T)),]
NC=aridSub[aridSub$group=="NB",]
aridSub=rbind(Csel,NC)

  fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                            data=aridSub, importance=TRUE, ntree=5000, replace=T)
  
  Contribution=fitRFarid$importance
  write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
  
  PredictionArid <- predict(fitRFarid)
  binded.dataRFarid=c()
  binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
  write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
 
  ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
  diag(prop.table(ctRFarid, 1))
  write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)

  Ammosper=aridData[aridData$complex=="Ammospermophilus leucurus",]
  PredictionNEWprob <- predict(fitRFarid,Ammosper,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Ammosper)
  binded.dataRFArid=cbind(Ammosper, PredictionNEWprob,PredictionNEW)  
    binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)

}
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Ammosper", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Ammospermophilus.tif")
  dev.off()

  
   
  ##################
binded.Predict=c()  

  for (i in 1:100) {
    aridSub=c()
  aridSub=aridData[aridData$complex!="Anaxyrus.punctatus.group",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)
  
  Anaxyrus=aridData[aridData$complex=="Anaxyrus.punctatus.group",]
  PredictionNEWprob <- predict(fitRFarid,Anaxyrus,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Anaxyrus)
  binded.dataRFArid=cbind(Anaxyrus, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)

  }  
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Anaxyrus", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Anaxyrus.tif")
  dev.off()
  
  ##################
  binded.Predict=c()  

  for (i in 1:100) {
   aridSub=c()
  aridSub=aridData[aridData$complex!="Auriparus flaviceps",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=13016, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)

  
  Auriparus=aridData[aridData$complex=="Auriparus flaviceps",]
  PredictionNEWprob <- predict(fitRFarid,Auriparus,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Auriparus)
  binded.dataRFArid=cbind(Auriparus, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)
}  
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Auriparus", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Auriparus.tif")
  dev.off()
  
  ##################
  binded.Predict=c()  

  for (i in 1:100) {
    aridSub=c()
  aridSub=aridData[aridData$complex!="Callilepla.californica-gambelli",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)

  
  Callilepla=aridData[aridData$complex=="Callilepla.californica-gambelli",]
  PredictionNEWprob <- predict(fitRFarid,Callilepla,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Callilepla)
  binded.dataRFArid=cbind(Callilepla, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)
}
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Callilepla", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Callilepla.tif")
  dev.off()
  

  ##################
  binded.Predict=c()  

  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Campylorhynchus brunneicapillus",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=14262, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)

  
  Campylo=aridData[aridData$complex=="Campylorhynchus brunneicapillus",]
  PredictionNEWprob <- predict(fitRFarid,Campylo,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Campylo)
  binded.dataRFArid=cbind(Campylo, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)
}
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Campylo", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Campylorhynchus.tif")
  dev.off()
  
  ##################
 binded.Predict=c()  

 for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Chaetodipus.baileyi.group",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)
  
  Chaeto=aridData[aridData$complex=="Chaetodipus.baileyi.group",]
  PredictionNEWprob <- predict(fitRFarid,Chaeto,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Chaeto)
  binded.dataRFArid=cbind(Chaeto, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)
}
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Chaeto", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Chaetodipus.tif")
  dev.off()
  
 
  ##################
binded.Predict=c()  

  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Dipodomys.merriami.group",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)

  
  Dipod=aridData[aridData$complex=="Dipodomys.merriami.group",]
  PredictionNEWprob <- predict(fitRFarid,Dipod,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Dipod)
  binded.dataRFArid=cbind(Dipod, PredictionNEWprob,PredictionNEW)
    binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)

  }
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Dipod", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Dipodomys.tif")
  dev.off()
  
  ##################
binded.Predict=c()  

  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Peromyscus.group",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)

  
  Peromys=aridData[aridData$complex=="Peromyscus.group",]
  PredictionNEWprob <- predict(fitRFarid,Peromys,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Peromys)
  binded.dataRFArid=cbind(Peromys, PredictionNEWprob,PredictionNEW)
     binded.Predict=rbind(binded.dataRFArid,binded.Predict)
     write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)

  }
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Peromyscus", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Peromyscus.tif")
  dev.off()
  
  ##################
binded.Predict=c()  

  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Pi.aberti-crissalis",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)

  
  Pipi=aridData[aridData$complex=="Pi.aberti-crissalis",]
  PredictionNEWprob <- predict(fitRFarid,Pipi,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Pipi)
  binded.dataRFArid=cbind(Pipi, PredictionNEWprob,PredictionNEW)
      binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)
}
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Pi.aberti-crissalis", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Pi.aberti-crissalis.tif")
  dev.off()
  
 
  ##################
binded.Predict=c()  

  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Pipilo fuscus",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=22782, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)
  
  Pipilio=aridData[aridData$complex=="Pipilo fuscus",]
  PredictionNEWprob <- predict(fitRFarid,Pipilio,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Pipilio)
  binded.dataRFArid=cbind(Pipilio, PredictionNEWprob,PredictionNEW)
     binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)
 }
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Pipilio", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Pipilio.tif")
  dev.off()
  
  ##################
binded.Predict=c()  

  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Po.melanura-californica",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)

  
  Po.mel.calif=aridData[aridData$complex=="Po.melanura-californica",]
  PredictionNEWprob <- predict(fitRFarid,Po.mel.calif,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Po.mel.calif)
  binded.dataRFArid=cbind(Po.mel.calif, PredictionNEWprob,PredictionNEW)
      binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)
}
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Po.mel.calif", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Po.melanura-californica.tif")
  dev.off()
  
  ##################
binded.Predict=c()  

  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="T.cinereum-binderei",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)
  
  Tcin.bin=aridData[aridData$complex=="T.cinereum-binderei",]
  PredictionNEWprob <- predict(fitRFarid,Tcin.bin,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Tcin.bin)
  binded.dataRFArid=cbind(Tcin.bin, PredictionNEWprob,PredictionNEW)
      binded.Predict=rbind(binded.dataRFArid,binded.Predict)
      write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)

  }
  plot(binded.dataRFArid$PredictionNEW, main="Prediction T.cin.bin", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="T.cinereum-binderei.tif")
  dev.off()
  
  ##################
binded.Predict=c()  

  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="Toxostoma lecontei",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=23171, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)

  
  Toxos=aridData[aridData$complex=="Toxostoma lecontei",]
  PredictionNEWprob <- predict(fitRFarid,Toxos,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Toxos)
  binded.dataRFArid=cbind(Toxos, PredictionNEWprob,PredictionNEW)
      binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)
}
  plot(binded.dataRFArid$PredictionNEW, main="Prediction Toxostoma", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="Toxostoma.tif")
  dev.off()
  
  ##################
binded.Predict=c()  

  for (i in 1:100) {
  aridSub=c()
  aridSub=aridData[aridData$complex!="V.luciae-ruficapilla",]
  C=aridSub[aridSub$group=="B",]
  Csel=C[(sample(nrow(C), size=24012, replace=T)),]
  NC=aridSub[aridSub$group=="NB",]
  aridSub=rbind(Csel,NC)
  
    fitRFarid <- randomForest(group ~ bio1 + bio2 + bio3 + bio7 + bio8 + bio9 + bio12 + bio14 + bio15 + bio18 + taxon,
                              data=aridSub, importance=TRUE, ntree=5000, replace=T)
    
    Contribution=fitRFarid$importance
    write.table(Contribution,file="fitRFaridResamp500.csv", sep=",", append=T)
    
    PredictionArid <- predict(fitRFarid)
    binded.dataRFarid=c()
    binded.dataRFarid=cbind(aridSub, PredictionArid) # bind initial data table with predicted values
    write.table(binded.dataRFarid,file="binded.dataArid_RF_resampl500.csv", sep=",", append=T)
    
    ctRFarid <- table(binded.dataRFarid$group, PredictionArid)
    diag(prop.table(ctRFarid, 1))
    write.table(ctRFarid, file="confusionTableRF_aridResampled500.csv", sep=",",append=T)
  
  
  Vluci.rufi=aridData[aridData$complex=="V.luciae-ruficapilla",]
  PredictionNEWprob <- predict(fitRFarid,Vluci.rufi,type="prob") #calculates probability for each group
  PredictionNEW <- predict(fitRFarid,Vluci.rufi)
  binded.dataRFArid=cbind(Vluci.rufi, PredictionNEWprob,PredictionNEW)
     binded.Predict=rbind(binded.dataRFArid,binded.Predict)
    write.table(binded.Predict[,c(20:21,33:38)], file="PredictOutspRFDown.csv", sep=',', append=T)
 }
  plot(binded.dataRFArid$PredictionNEW, main="Prediction V.lu.ruf", beside=F)
  dev.copy(tiff,width = 1000, height = 1000, compression="none",file="V.luciae-ruficapilla.tif")
  dev.off()
  
  
